package wusthelper.web.api.v2;

import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTVerificationException;
import lombok.extern.slf4j.Slf4j;

import java.time.Duration;
import java.util.Date;

@Slf4j
public class Token {

    private final static String SECRET = "LingHangStudio.WustHelper";

    private final static long EXPIRE_SCD = Duration.ofDays(3).toSeconds();

    private static final Algorithm jwtAlgorithm = Algorithm.HMAC256(SECRET);

    /**
     * 签发Token
     *
     * @return
     */
    public static String signToken(Long uid, String studentNumber) {
        try {
            Date now = new Date();
            Date expireAt = new Date(now.getTime() + EXPIRE_SCD);

            return JWT.create()
                    .withClaim("StuId", uid.toString())
                    .withClaim("StuNum", studentNumber)
                    .withIssuedAt(now)
                    .withExpiresAt(expireAt)
                    .sign(jwtAlgorithm);
        } catch (Exception e) {
            log.error("[{}]:Token签发工具类>签发Token异常, 空指针异常: uid={},studentNumber={}",
                    Thread.currentThread().getStackTrace()[1].getMethodName(),
                    uid, studentNumber);
            throw new RuntimeException("[JwtUtil.signToken()]");
        }
    }

    /**
     * 校验Token
     *
     * @param token
     * @return
     */
    public static boolean verifyToken(String token) {
        try {
            JWT.require(jwtAlgorithm)
                    .build()
                    .verify(token);
        } catch (JWTVerificationException e) {
            return false;
        }

        return true;
    }

    /**
     * Token 负载StuId
     *
     * @param token
     * @return
     */
    public static String getUid(String token) {
        return JWT.decode(token).getClaim("StuId").asString();
    }

    /**
     * Token 负载StuNum
     *
     * @param token
     * @return
     */
    public static String getStudentNumber(String token) {
        return JWT.decode(token).getClaim("StuNum").asString();
    }
}
