package wusthelper.web.service.campus.graduate;

import cn.wustlinghang.mywust.data.global.StudentInfo;
import org.springframework.stereotype.Service;
import wusthelper.code.ServiceCode;
import wusthelper.web.data.entity.CookieType;
import wusthelper.web.exception.ServiceException;
import wusthelper.web.rpc.graduate.GraduateStudentInfoRemote;
import wusthelper.web.service.cookie.CookieManager;
import wusthelper.web.service.student.StudentService;

@Service
public class GraduateStudentInfoService {
    private final GraduateStudentInfoRemote graduateStudentInfoRemote;

    private final CookieManager cookieManager;

    private final StudentService studentService;

    public GraduateStudentInfoService(GraduateStudentInfoRemote graduateStudentInfoRemote,
                                      CookieManager cookieManager,
                                      StudentService studentService) {

        this.graduateStudentInfoRemote = graduateStudentInfoRemote;
        this.cookieManager = cookieManager;
        this.studentService = studentService;
    }

    public StudentInfo getStudentInfo(String user) {
        String cookie = cookieManager.getCookie(user, CookieType.Graduate);

        return getStudentInfo(user, cookie);
    }

    public StudentInfo getStudentInfo(String user, String cookie) {
        var response = graduateStudentInfoRemote.get(cookie);
        if (response.code() != ServiceCode.Ok) {
            ServiceException.of(response.code());
        }

        var studentInfo = response.data();

        studentService.saveOrUpdateUserAsync(user, studentInfo);
        return studentInfo;
    }
}