package wusthelper.web.service.campus.undergrad;

import cn.wustlinghang.mywust.data.global.StudentInfo;
import org.springframework.stereotype.Service;
import wusthelper.code.ServiceCode;
import wusthelper.web.data.entity.CookieType;
import wusthelper.web.exception.ServiceException;
import wusthelper.web.rpc.undergrad.UndergradStudentInfoRemote;
import wusthelper.web.service.cookie.CookieManager;
import wusthelper.web.service.student.StudentService;
import wusthelper.web.util.PasswordCodec;

@Service
public class UndergradStudentInfoService {

    private final UndergradStudentInfoRemote undergradStudentInfoRemote;

    private final CookieManager cookieManager;

    private final StudentService studentService;

    public UndergradStudentInfoService(UndergradStudentInfoRemote undergradStudentInfoRemote,
                                       CookieManager cookieManager,
                                       StudentService studentService) {

        this.undergradStudentInfoRemote = undergradStudentInfoRemote;
        this.cookieManager = cookieManager;
        this.studentService = studentService;
    }

    public StudentInfo getStudentInfo(String user) {
        String cookie = cookieManager.getCookie(user, CookieType.Undergrad);

        return getStudentInfo(user, cookie);
    }

    public StudentInfo getStudentInfo(String user, String cookie) {
        var rpcResp = undergradStudentInfoRemote.get(cookie);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.of(rpcResp.code());
        }

        var studentInfo = rpcResp.data();

        studentService.saveOrUpdateUserAsync(user, studentInfo);
        return studentInfo;
    }
}