package wusthelper.web.service.student;

import cn.wustlinghang.mywust.data.global.StudentInfo;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.yitter.idgen.YitIdHelper;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.stereotype.Service;
import wusthelper.data.dao.mapper.StudentMapper;
import wusthelper.data.entity.Student;
import wusthelper.web.util.Converter;

import java.util.concurrent.CompletableFuture;

@Service
@EnableAsync
public class StudentService {
    private final StudentMapper studentMapper;

    public StudentService(StudentMapper studentMapper) {
        this.studentMapper = studentMapper;
    }

    @Async
    public CompletableFuture<Student> saveOrUpdateUserAsync(String username, StudentInfo studentInfo) {
        var student = Converter.convert(studentInfo);
        if (student.getStuNum() == null) {
            student.setStuNum(username);
        }

        var query = new QueryWrapper<Student>()
                .eq("stuNum", username)
                .eq("deleted", 0);

        // （按学号）检查用户信息是否已经存在数据库中，已存在则更新，否则新增信息
        var studentExists = studentMapper.exists(query);
        if (studentExists) {
            studentMapper.update(student, query);
        } else {
            student.setId(YitIdHelper.nextId());
            studentMapper.insert(student);
        }

        return CompletableFuture.completedFuture(student);
    }
}
