package wusthelper.code;

import java.util.HashMap;
import java.util.Map;

public class ServiceCode {
    public static final int Ok                  = 0;  // ok
    public static final int ServerInternalError = -2; // 服务器内部错误
    public static final int ApiNotImplement     = -1; // 接口未实现

    // 所有模块共用
    public static final int Unknown         = 10_000; // 未知错误
    public static final int RequestInvalid  = 10_001; // 请求无效
    public static final int ParamWrong      = 10_002; // 请求无效
    public static final int CookieInvalid   = 10_003; // 提供的cookie无效
    public static final int NetworkError    = 10_004; // 网络错误
    public static final int RpcError        = 10_005; // 上游RPC错误
    public static final int ParseError      = 10_006; // 解析错误

    // 主模块
    public static final int UserNotExists = 20_001; // 用户不存在

    // 本科生
    public static final int UndergradUserNotExists          = 30_001; // 本科生：用户不存在
    public static final int UndergradUserBanned             = 30_002; // 本科生：封号
    public static final int UndergradUserDisabled           = 30_003; // 本科生：用户账号禁用
    public static final int UndergradPasswordNeedModify     = 30_004; // 本科生：用户密码需要更改
    public static final int UndergradBannedInExclusiveTime  = 30_005; // 本科生：专属选课时间段账号被禁用（--> _ --）
    public static final int UndergradNeedEvaluate           = 30_006; // 本科生：需要评教

    // 研究生
    public static final int GraduatePasswordWrong   = 40_001; // 研究生：密码错误
    public static final int GraduateCaptchaWrong    = 40_002; // 研究生：验证码错误

    // 图书馆
    public static final int LibraryUserNotExists        = 50_001; // 图书馆：用户不存在
    public static final int LibraryUserBanned           = 50_002; // 图书馆：封号
    public static final int LibraryUserDisabled         = 50_003; // 图书馆：用户账号禁用
    public static final int LibraryPasswordNeedModify   = 50_004; // 图书馆：用户密码需要更改

    // 物理实验
    public static final int PhysicsPasswordWrong        = 60_001; // 物理实验：用户不存在
    public static final int PhysicsUserNotCurrentTerm   = 60_002; // 物理实验：用户不在当前学期

    private static final Map<Integer, String> text = new HashMap<>(128);

    // 错误码文案
    static {
        text.put(Ok, "ok");
        text.put(ServerInternalError, "服务器内部错误");
        text.put(ApiNotImplement, "接口未实现");

        // 主模块
        text.put(UserNotExists, "用户不存在");

        // 所有模块共用
        text.put(Unknown, "未知错误");
        text.put(RequestInvalid, "请求无效");
        text.put(CookieInvalid, "提供的cookie无效");
        text.put(NetworkError, "网络错误");
        text.put(RpcError, "上游RPC错误");
        text.put(ParseError, "解析错误");

        // 本科生
        text.put(UndergradUserNotExists, "本科生：用户不存在");
        text.put(UndergradUserBanned, "本科生：封号");
        text.put(UndergradUserDisabled, "本科生：用户账号禁用");
        text.put(UndergradPasswordNeedModify, "本科生：用户密码需要更改");
        text.put(UndergradBannedInExclusiveTime, "本科生：专属选课时间段账号被禁用（--> _ --）");
        text.put(UndergradNeedEvaluate, "本科生：需要评教");

        // 研究生
        text.put(GraduatePasswordWrong, "研究生：密码错误");
        text.put(GraduateCaptchaWrong, "研究生：验证码错误");

        // 图书馆
        text.put(LibraryUserNotExists, "图书馆：用户不存在");
        text.put(LibraryUserBanned, "图书馆：封号");
        text.put(LibraryUserDisabled, "图书馆：用户账号禁用");
        text.put(LibraryPasswordNeedModify, "图书馆：用户密码需要更改");

        // 物理实验
        text.put(PhysicsPasswordWrong, "物理实验：用户不存在");
        text.put(PhysicsUserNotCurrentTerm, "物理实验：用户不在当前学期");
    }

    private final int code;

    private final String description;

    ServiceCode(int code, String description) {
        this.code = code;
        this.description = description;
    }

    ServiceCode(int code) {
        this(code, getDescribe(code));
    }

    public int getCode() {
        return code;
    }

    public String getDescription() {
        return description;
    }

    public static String getDescribe(int code) {
        return text.get(code);
    }

    public static ServiceCode of(int code) {
        return new ServiceCode(code);
    }
//
//    public static class Code {
//        // 所有模块共用
//        public static final ErrorCode Unknown           = ErrorCode.of(10_000); // 未知错误
//        public static final ErrorCode RequestInvalid    = ErrorCode.of(10_001); // 请求无效
//        public static final ErrorCode CookieInvalid     = ErrorCode.of(10_002); // 提供的cookie无效
//        public static final ErrorCode NetworkError      = ErrorCode.of(10_003); // 网络错误
//        public static final ErrorCode RpcError          = ErrorCode.of(10_004); // 上游RPC错误
//        public static final ErrorCode ParseError        = ErrorCode.of(10_005); // 解析错误
//
//        // 本科生
//        public static final ErrorCode UndergradUserNotExists            = ErrorCode.of(20_001); // 本科生：用户不存在
//        public static final ErrorCode UndergradUserBanned               = ErrorCode.of(20_002); // 本科生：封号
//        public static final ErrorCode UndergradUserDisabled             = ErrorCode.of(20_003); // 本科生：用户账号禁用
//        public static final ErrorCode UndergradPasswordNeedModify       = ErrorCode.of(20_004); // 本科生：用户密码需要更改
//        public static final ErrorCode UndergradBannedInExclusiveTime    = ErrorCode.of(20_005); // 本科生：专属选课时间段账号被禁用（--> _ --）
//        public static final ErrorCode UndergradNeedEvaluate             = ErrorCode.of(20_006); // 本科生：需要评教
//
//        // 研究生
//        public static final ErrorCode GraduatePasswordWrong = ErrorCode.of(30_001); // 研究生：密码错误
//        public static final ErrorCode GraduateCaptchaWrong  = ErrorCode.of(30_002); // 研究生：验证码错误
//
//        // 图书馆
//        public static final ErrorCode LibraryUserNotExists      = ErrorCode.of(40_001); // 图书馆：用户不存在
//        public static final ErrorCode LibraryUserBanned         = ErrorCode.of(40_002); // 图书馆：封号
//        public static final ErrorCode LibraryUserDisabled       = ErrorCode.of(40_003); // 图书馆：用户账号禁用
//        public static final ErrorCode LibraryPasswordNeedModify = ErrorCode.of(40_004); // 图书馆：用户密码需要更改
//
//        // 物理实验
//        public static final ErrorCode PhysicsPasswordWrong      = ErrorCode.of(50_001); // 物理实验：用户不存在
//        public static final ErrorCode PhysicsUserNotCurrentTerm = ErrorCode.of(50_002); // 物理实验：用户不在当前学期
//    }
}
