package wusthelper.internal.rpc.exception;

import java.util.StringJoiner;

public class PhysicsRpcException extends RpcException {
    public PhysicsRpcException(TypeCode typeCode,
                               SubModuleCode subModuleCode,
                               ErrorCode errorCode) {
        super(PHYSICS_MODULE,
                typeCode.ordinal(),
                subModuleCode.ordinal() * 100 + errorCode.ordinal(),
                new StringJoiner("/")
                        .add("PHYSICS")
                        .add(typeCode.name())
                        .add(subModuleCode.name())
                        .add(errorCode.name())
                        .toString()
        );
    }

    /**
     * 异常类型编码
     */
    public enum TypeCode {
        // 网络异常类型
        NETWORK_EXCEPTION,
        // 参数异常类型
        PARAM_EXCEPTION,
        // 权限认证异常类型
        AUTH_EXCEPTION,
        // 网页解析异常类型
        PARSE_EXCEPTION,
        // 其他的异常类型
        OTHER_EXCEPTION
    }

    /**
     * 子模块编码
     */
    public enum SubModuleCode {
        COMMON, AUTH, COURSE_TABLE, SCORE
    }

    /**
     * 具体错误编码
     */
    public enum ErrorCode {
        REQUEST_INVALID,
        PARAM_INVALID,
        COOKIE_INVALID,
        NETWORK_ERROR,
        PARSE_ERROR,

        AUTH_PASSWORD_WRONG,
        AUTH_UNKNOWN_ERROR,

        AUTH_USER_NOT_CURRENT_TERM
    }
}
