package wusthelper.internal.rpc.exception;

public abstract class RpcException extends RuntimeException {
    protected final int code;

    public static final int UNDERGRAD_MODULE = 1;
    public static final int GRADUATE_MODULE = 2;
    public static final int LIBRARY_MODULE = 3;
    public static final int PHYSICS_MODULE = 4;

    private static final int MODULE_CODE_OFFSET = 100_0000;
    private static final int TYPE_CODE_OFFSET = 1_0000;
    
    public RpcException(int code, String message) {
        super(message);
        this.code = code;
    }

    public RpcException(int code) {
        this(code, String.valueOf(code));
    }

    public RpcException(int module, int type, int exceptionCode) {
        this((module * MODULE_CODE_OFFSET) + (type * TYPE_CODE_OFFSET) + (exceptionCode));
    }

    public RpcException(int module, int type, int exceptionCode, String message) {
        this((module * MODULE_CODE_OFFSET) + (type * TYPE_CODE_OFFSET) + (exceptionCode), message);
    }

    public int getCode() {
        return code;
    }

    public static RpcException ApiNotImplement() {
        return new RpcException(-1, "接口未实现") {};
    }

    public static int toIntCode(int module, int type, int exceptionCode) {
        return (module * MODULE_CODE_OFFSET) + (type * TYPE_CODE_OFFSET) + (exceptionCode);
    }
}
