package wusthelper.internal.graduate.api.http.v1.interceptor;

import wusthelper.internal.graduate.api.http.v1.handler.BaseExceptionHandler;
import wusthelper.internal.rpc.response.RpcResponseDto;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.ws.rs.WebApplicationException;
import jakarta.ws.rs.core.HttpHeaders;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.ext.Provider;
import jakarta.ws.rs.ext.WriterInterceptor;
import jakarta.ws.rs.ext.WriterInterceptorContext;

import java.io.IOException;

@Provider
public class ResponseWrapperInterceptor implements WriterInterceptor {
    private final ObjectMapper objectMapper;

    public ResponseWrapperInterceptor(ObjectMapper objectMapper) {
        this.objectMapper = objectMapper;
    }

    @Override
    public void aroundWriteTo(WriterInterceptorContext context) throws IOException, WebApplicationException {
        boolean hasException = context.getHeaders().get(BaseExceptionHandler.EXCEPTION_HEADER_KEY) != null;
        if (!hasException) {
            Object data = context.getEntity();
            RpcResponseDto<Object> wrappedResponse = RpcResponseDto.success(data);
            String json = objectMapper.writeValueAsString(wrappedResponse);
            context.getHeaders().putSingle(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_JSON);
            context.setEntity(json);
        }

        context.proceed();
    }
}
