package wusthelper.internal.library.services;

import cn.wustlinghang.mywust.core.request.service.library.BookCoverImageUrlApiService;
import cn.wustlinghang.mywust.exception.ApiException;
import wusthelper.internal.rpc.exception.LibraryRpcException;
import wusthelper.internal.rpc.exception.RpcException;
import jakarta.enterprise.context.ApplicationScoped;

import java.io.IOException;
import java.util.List;
import java.util.Map;

@ApplicationScoped
public class BookCoverImageUrlService extends BaseService {
    private final BookCoverImageUrlApiService api;

    public BookCoverImageUrlService(BookCoverImageUrlApiService api) {
        this.api = api;
    }

    public List<String> getBookCoverImageUrl(String isbn) throws RpcException {
        try {
            return api.getBookCoverImageUrl(isbn);
        } catch (ApiException e) {
            throw wrapApiException(e, LibraryRpcException.SubModuleCode.COVER_IMAGE);
        } catch (IOException e) {
            throw new LibraryRpcException(
                    LibraryRpcException.TypeCode.NETWORK_EXCEPTION,
                    LibraryRpcException.SubModuleCode.COVER_IMAGE,
                    LibraryRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

    public Map<String, List<String>> getBookCoverImageUrl(List<String> isbnList) throws RpcException {
        try {
            return api.getBookCoverImageUrl(isbnList);
        } catch (ApiException e) {
            throw wrapApiException(e, LibraryRpcException.SubModuleCode.COVER_IMAGE);
        } catch (IOException e) {
            throw new LibraryRpcException(
                    LibraryRpcException.TypeCode.NETWORK_EXCEPTION,
                    LibraryRpcException.SubModuleCode.COVER_IMAGE,
                    LibraryRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

}
