package wusthelper.internal.library.services;

import cn.wustlinghang.mywust.core.request.service.auth.LibraryLogin;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import wusthelper.internal.rpc.exception.LibraryRpcException;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class LoginService {
    private final RequestClientOption option;
    private final LibraryLogin libraryLogin;

    public LoginService(RequestClientOption option,
                        LibraryLogin libraryLogin) {
        this.option = option;
        this.libraryLogin = libraryLogin;
    }

    public String login(String username, String password) throws LibraryRpcException {
        try {
            return libraryLogin.getLoginCookie(username, password, option);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new LibraryRpcException(
                    LibraryRpcException.TypeCode.NETWORK_EXCEPTION,
                    LibraryRpcException.SubModuleCode.AUTH,
                    LibraryRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

    public boolean verify(String cookie) throws LibraryRpcException {
        try {
            return libraryLogin.checkCookie(cookie, option);
        } catch (IOException e) {
            throw new LibraryRpcException(
                    LibraryRpcException.TypeCode.NETWORK_EXCEPTION,
                    LibraryRpcException.SubModuleCode.AUTH,
                    LibraryRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

    private LibraryRpcException wrapApiException(ApiException e) {
        LibraryRpcException.ErrorCode errorCode = switch (e.getCode()) {
            case NETWORK_EXCEPTION -> LibraryRpcException.ErrorCode.NETWORK_ERROR;
            case UNI_LOGIN_PASSWORD_WRONG -> LibraryRpcException.ErrorCode.AUTH_PASSWORD_WRONG;
            case UNI_LOGIN_USER_NOT_EXISTS -> LibraryRpcException.ErrorCode.AUTH_USER_NOT_EXISTS;
            case UNI_LOGIN_USER_BANNED -> LibraryRpcException.ErrorCode.AUTH_USER_BANNED;
            case UNI_LOGIN_USER_DISABLED -> LibraryRpcException.ErrorCode.AUTH_USER_DISABLED;
            case UNI_LOGIN_NEED_CHANGE_PASSWORD -> LibraryRpcException.ErrorCode.AUTH_NEED_CHANGE_PASSWORD;
            case UNI_LOGIN_USER_NOT_ONLY, UNI_LOGIN_NEED_TFA, UNI_LOGIN_NO_REGISTER
                    -> LibraryRpcException.ErrorCode.AUTH_UNKNOWN_ERROR;
            default -> {
                log.error("图书馆：登录代理请求异常，异常未处理");
                log.error("异常：", e);
                yield LibraryRpcException.ErrorCode.AUTH_UNKNOWN_ERROR;
            }
        };

        return new LibraryRpcException(
                LibraryRpcException.TypeCode.AUTH_EXCEPTION,
                LibraryRpcException.SubModuleCode.AUTH,
                errorCode
        );
    }
}
