package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradExamDelayParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradExamDelayApiService;
import cn.wustlinghang.mywust.data.undergrad.ExamDelayApplication;
import cn.wustlinghang.mywust.exception.ApiException;
import wusthelper.internal.rpc.exception.UndergradRpcException;
import wusthelper.internal.rpc.exception.RpcException;
import jakarta.enterprise.context.ApplicationScoped;

import java.io.IOException;
import java.util.List;

@ApplicationScoped
public class ExamDelayApplicationService extends BaseService {
    private final UndergradExamDelayApiService examDelayApiService;
    private final UndergradExamDelayParser examDelayParser;

    public ExamDelayApplicationService(UndergradExamDelayApiService examDelayApiService,
                                       UndergradExamDelayParser examDelayParser) {
        this.examDelayApiService = examDelayApiService;
        this.examDelayParser = examDelayParser;
    }

    public String getExamDelayApplications(String cookie, String term, String activityId)
            throws RpcException {
        try {
            return examDelayApiService.getPage(term, activityId, cookie);
        } catch (ApiException e) {
            throw wrapApiException(e, UndergradRpcException.SubModuleCode.EXAM_DELAY_APPLICATION);
        } catch (IOException e) {
            throw new UndergradRpcException(
                    UndergradRpcException.TypeCode.NETWORK_EXCEPTION,
                    UndergradRpcException.SubModuleCode.EXAM_DELAY_APPLICATION,
                    UndergradRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

    public List<ExamDelayApplication> parseExamDelayApplications(String data) throws RpcException {
        try {
            return examDelayParser.parse(data);
        } catch (Exception e) {
            throw new UndergradRpcException(
                    UndergradRpcException.TypeCode.PARSE_EXCEPTION,
                    UndergradRpcException.SubModuleCode.EXAM_DELAY_APPLICATION,
                    UndergradRpcException.ErrorCode.PARSE_ERROR
            );
        }
    }
}
