package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradStudentInfoPageParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradStudentInfoApiService;
import cn.wustlinghang.mywust.data.global.StudentInfo;
import cn.wustlinghang.mywust.exception.ApiException;
import wusthelper.internal.rpc.exception.UndergradRpcException;
import wusthelper.internal.rpc.exception.RpcException;
import jakarta.enterprise.context.ApplicationScoped;

import java.io.IOException;

@ApplicationScoped
public class StudentInfoService extends BaseService {
    private final UndergradStudentInfoApiService studentInfoApiService;
    private final UndergradStudentInfoPageParser studentInfoPageParser;

    public StudentInfoService(UndergradStudentInfoApiService studentInfoApiService,
                              UndergradStudentInfoPageParser studentInfoPageParser) {
        this.studentInfoApiService = studentInfoApiService;
        this.studentInfoPageParser = studentInfoPageParser;
    }

    public String getStudentInfoPage(String cookie) throws RpcException {
        try {
            return studentInfoApiService.getPage(cookie);
        } catch (ApiException e) {
            throw wrapApiException(e, UndergradRpcException.SubModuleCode.STUDENT_INFO);
        } catch (IOException e) {
            throw new UndergradRpcException(
                    UndergradRpcException.TypeCode.NETWORK_EXCEPTION,
                    UndergradRpcException.SubModuleCode.STUDENT_INFO,
                    UndergradRpcException.ErrorCode.NETWORK_ERROR
            );
        }
    }

    public StudentInfo parseStudentInfo(String data) throws RpcException {
        try {
            return studentInfoPageParser.parse(data);
        } catch (Exception e) {
            throw new UndergradRpcException(
                    UndergradRpcException.TypeCode.PARSE_EXCEPTION,
                    UndergradRpcException.SubModuleCode.STUDENT_INFO,
                    UndergradRpcException.ErrorCode.PARSE_ERROR
            );
        }
    }
}
